set size 0.60,0.60
set style data lines
set term pslatex solid color norotate

set lmargin 3
set rmargin 1
set bmargin 1
set tmargin 1

set pointsize 1.0; unset key

dir  = 'Data/'

xmin=0.0; xmax=0.42; dx = xmax-xmin; 
set xra [xmin:xmax]
set xtics (''0, ''0.1, ''0.2, ''0.3, ''0.4)

ymin=-2.1; ymax=1.0; dy = ymax-ymin; set ytics -2,1
set yra [ymin:ymax]

c = 8.0*pi 

#
# Case kappa=0.05
#

kappa = 0.05
eta   = 0.9170206
eps   = 1.174081
alpha = 0.2451220

ga = (eps**2 - 1.0) / eps**2
gb = (eps-1.0)**2   / eps**2
gc = (eps-1.0)      / eps
ge = alpha          / eps**2

fa(x) = -S * (kappa*ga/(c*eta)) * x**2
fb(x) = -S * (kappa*gb/(c*eta)) * x**2
fc(x) = -S * (kappa*gc/(c*eta)) * x**2
fe(x) =  S * (kappa*ge/(c*eta)) * x**2

S=-1.0e5

set label 1 '(a) $\kappa=0.05$'                at xmax-0.35*dx, ymax - 0.10*dy
set label 2 '$\sigma \times 10^{5}$'           at xmin+0.02*dx, ymax - 0.10*dy
set label 3 '${\bf f}_{\tt elstr}$'            at 0.16        ,-1.77
set label 4 '${\bf f}_{\tt elstr}+{\bf f}_b$'  at 0.20        ,-1.20
set label 5 '${\bf f}_{\tt elstr}+{\bf f}_a$'  at 0.16        , 0.40
set label 6 '${\bf f}_H$'                      at 0.37        ,-1.13

set out 'Src_12a.tex'

file = 'L_e_p=0_kappa=0.05_N=150'

plot dir.file ev 2 u ($1):($3)*S with p pt 7 ,\
     fe(x)       w l lt  1 lw 2, \
     fe(x)+fa(x) w l lt  3 lw 2, \
     fe(x)+fb(x) w l lt  4 lw 2, \
     fe(x)+fc(x) w l lt -1 lw 2

#
# Case kappa=0.10
#

ymin=-2.0; ymax=1.1; dy = ymax-ymin; set ytics -2,1
set yra [ymin:ymax]

kappa = 0.10
eta   = 0.8230880
eps   = 1.382958
alpha = 0.7373757

ga = (eps**2 - 1.0) / eps**2
gb = (eps-1.0)**2   / eps**2
gc = (eps-1.0)      / eps
ge = alpha          / eps**2

fa(x) = -S * (kappa*ga/(c*eta)) * x**2
fb(x) = -S * (kappa*gb/(c*eta)) * x**2
fc(x) = -S * (kappa*gc/(c*eta)) * x**2
fe(x) =  S * (kappa*ge/(c*eta)) * x**2

S = -1.0e4

set label 1 '(b) $\kappa=0.10$'                at xmax-0.35*dx, ymax - 0.10*dy
set label 2 '$\sigma \times 10^{4}$'           at xmin+0.02*dx, ymax - 0.10*dy
set label 3 '${\bf f}_{\tt elstr}$'            at 0.25        , -1.77
set label 4 '${\bf f}_{\tt elstr}+{\bf f}_b$'  at 0.32        , -1.40
set label 5 '${\bf f}_{\tt elstr}+{\bf f}_a$'  at 0.31        ,  0.28
set label 6 '${\bf f}_H$'                      at 0.38        , -0.60
 
set out 'Src_12b.tex'

file = 'L_e_p=0_kappa=0.10_N=150'

plot dir.file ev 2 u ($1):($3)*S with p pt 7 ,\
     fe(x)       w l lt  1 lw 2, \
     fe(x)+fa(x) w l lt  3 lw 2, \
     fe(x)+fb(x) w l lt  4 lw 2, \
     fe(x)+fc(x) w l lt -1 lw 2

#
# Case kappa=0.20
#

set xtics 0,0.1

ymin=-2.5; ymax=0.2; set yra [ymin:ymax]; set ytics -2,1

kappa = 0.20
eta   = 0.5782101
eps   = 2.087716
alpha = 4.254165

ga = (eps**2 - 1.0) / eps**2
gb = (eps-1.0)**2   / eps**2
gc = (eps-1.0)      / eps
ge = alpha          / eps**2

fa(x) = -S * (kappa*ga/(c*eta)) * x**2
fb(x) = -S * (kappa*gb/(c*eta)) * x**2
fc(x) = -S * (kappa*gc/(c*eta)) * x**2
fe(x) =  S * (kappa*ge/(c*eta)) * x**2

S = -1.0e3

set label 1 '(c) $\kappa=0.20$'                at xmax-0.35*dx, ymax - 0.080*dy
set label 2 '$\sigma \times 10^{3}$'           at xmin+0.02*dx, ymax - 0.250*dy
set label 3 '$e$'                              at xmax-0.20*dx, ymin + 0.032*dy
set label 4 '${\bf f}_{\tt elstr}$'            at 0.20        , -0.88
set label 5 '${\bf f}_{\tt elstr}+{\bf f}_b$'  at 0.26        , -2.10
set label 6 '${\bf f}_{\tt elstr}+{\bf f}_a$'  at 0.20        , -1.60
set label 7 '${\bf f}_H$'                      at 0.39        , -1.15

a=0.38;set arrow 1 from 0.30,-2.00 to  a, fe(a)+fb(a)
b=0.35;set arrow 2 from 0.25,-1.55 to  b, fe(b)+fa(b)
 
set out 'Src_12c.tex'

file = 'L_e_p=0_kappa=0.20_N=150'

plot dir.file ev 2 u ($1):($3)*S with p pt 7 ,\
     fe(x)       w l lt  1 lw 2, \
     fe(x)+fa(x) w l lt  3 lw 2, \
     fe(x)+fb(x) w l lt  4 lw 2, \
     fe(x)+fc(x) w l lt -1 lw 2

exit
