  include 'blocks.f90'
  include 'formats.f90'
  include 'constants.f90'
  program PF_eps
    use blocks
    use formats
    implicit none
      
    real*8    :: p, de, RL_a, RL_b, RL_0, RL, dist
    real*8    :: fdist, error, d, da, db, eps, Fa_i, Fb_i
    real*8    :: za_old, zb_old, sum
    real*8    :: kappa_min, kappa_max, dkappa, D0
    real*8    :: b1, b2, beta, cfc1, cfc2, cfc3, cfc4
      
    integer*4 :: info, ip, ip_fail, i, iter, iter_inner, iter_outer

    logical*4 :: flag

    real*8, allocatable, dimension(:) :: y, ya, yb, z, za, zb, F
    real*8, allocatable, dimension(:) :: Fa, Fb

    external check_pars, update_z, make_F, make_Fa, make_Fb, make_Fa_i, make_Fb_i, fdist

    Job = 'PF_eps'

    write(6,f1) '=========================================='
    write(6,f1) '=========================================='
    write(6,f1) '=========================================='
    call check_pars(info)
    write(6,f1)   '******************************************'
    if(info .eq. 0) then
       write(6,f1) 'PF_eps: Parameters checked for sanity'
    else if(info .gt. 0) then
       write(6,f2) 'PF_eps: There were errors on input, info=', info
       stop
    else 
       write(6,f2) 'PF_eps: There were warnings on input, info=', info
    end if

    kappa_min = rz
    kappa_max = kappa
    dkappa    = (kappa_max-kappa_min)/dfloat(Np-1)
    p         = p_min
    de        = e_max
    if(de .le. small) then
       write(6,f5) 'PF_eps: de<=small (fatal); de=', de
       stop
    end if

    write(6,f1) 'PF_eps computes eps as a function of kappa at fixed p:'
    write(6,f1) 'File "eps.dat" : kappa, eps  [ = 1 / (1-4*pi*D0) -- Eq.(50a)   ]'
    write(6,f1) 'File "err.dat" : kappa, err  [ err = sqrt( Sum(Eq.39)^2 / N ) ]'
    write(6,f1) 'where'
    write(6,f3) '[set by code         ] -- kappa_min: ', sngl(rz)
    write(6,f3) '[from parameter kappa] -- kappa_max: ', sngl(kappa)
    write(6,f3) '[from parameter p_min] -- p        : ', sngl(p)
    write(6,f3) '[from parameter e_max] -- de       : ', sngl(de)
    write(6,f1)   '******************************************'

    allocate(z(1:N))
    allocate(y(1:N))
    allocate(F(1:N))

    allocate(ya(1:N)); allocate(yb(1:N))
    allocate(za(1:N)); allocate(zb(1:N))
    allocate(Fa(1:N)); allocate(Fb(1:N))

    open(unit=71, file='eps.dat', status='unknown')
    open(unit=72, file='err.dat', status='unknown')

    flag = .false.

    ip_loop: do ip=1,Np

       kappa = kappa_min + dkappa*dfloat(ip-1)
       beta  = pi*kappa*A0
       cfc1  = ru + beta
       cfc2  = ru + two*beta
       cfc3  = four*(ru+beta)
       cfc4  = two + beta

       F = rz; 
       F(1) = F(1) + p; F(N) = F(N) - p
       call update_z(F, z, error)
       if(error .gt. small) then
          write(*,*) 'PF_eps: Error in update_z at Point A (fatal):', error
          stop
       end if
!       RL = z(N) - z(1)

       iter = 0
       l1: do
          iter = iter + 1
          call make_F(z, F)
          F(1) = F(1) + p; F(N) = F(N) - p
          y    = z
          call update_z(F, z, error)
          if(error .gt. small) then
             write(6,f5) 'PF_eps: Error in update_z at Point B (fatal):', error
             stop
          end if
          if(fdist(z,y) .le. th1) exit l1
       end do l1

!       RL   = z(N) - z(1)
!       RL_0 = RL
        RL_0   = z(N) - z(1)
      
       za = z; zb = z
       ya = za; yb = zb

       iter_outer = 0

       iter_outer_loop: do

          iter_outer = iter_outer + 1

          if(iter_outer .gt. iter_max) then
             write(6,f1) 'PF_eps: maximum number of outer iterations has been reached'
             flag = .true.
             ip_fail = ip
             exit ip_loop
          end if

          i_loop: do i=1,N
      
             za_old = za(i); zb_old=zb(i)

             iter_inner = 0

             iter_inner_loop: do 

                iter_inner = iter_inner + 1

                if(iter_inner .gt. iter_max) then
                   write(6,f1) 'PF_eps: maximum number of inner iterations has been reached'
                   flag = .true.
                   ip_fail = ip
                   exit ip_loop
                end if
                
                call make_Fa_i(i, p, de, za, zb, Fa_i)
                call make_Fb_i(i, p, de, za, zb, Fb_i)

                if     (i .eq. 1) then
                   b1 = za(2) - ru + Fa_i
                   b2 = zb(2) - ru + Fb_i
                   za(1) = (cfc1*b1 +     beta *b2) / cfc2
                   zb(1) = (beta*b1 + (ru+beta)*b2) / cfc2
                else if(i .lt. N) then
                   b1 = za(i-1) + za(i+1) + Fa_i
                   b2 = zb(i-1) + zb(i+1) + Fb_i
                   za(i) = (cfc4*b1 + beta*b2) / cfc3
                   zb(i) = (beta*b1 + cfc4*b2) / cfc3
                else
                   b1 = za(N-1) + ru + Fa_i
                   b2 = zb(N-1) + ru + Fb_i
                   za(N) = (cfc1*b1 + beta*b2) / cfc2
                   zb(N) = (beta*b1 + cfc1*b2) / cfc2
                end if
         
                dist = dsqrt((za(i)-za_old)**2 + (zb(i)-zb_old)**2)
                if(dist .le. th1) exit iter_inner_loop
                za_old = za(i); zb_old = zb(i)
                
             end do iter_inner_loop
         
          end do i_loop

          dist = (fdist(za,ya) + fdist(zb,yb))/two
          if(dist .le. th2) exit iter_outer_loop
          ya = za; yb=zb

       end do iter_outer_loop

       call make_Fa(p, de, za, zb, Fa)
       call make_Fb(p, de, za, zb, Fb)
       sum = rz
       sum = sum + (za(2) - za(1) - ru + Fa(1))**2 + (zb(2) - zb(1) - ru + Fb(1))**2
       do i=2,N-1
          sum = sum + (za(i-1) - two*za(i) + za(i+1) + Fa(i))**2 + (zb(i-1) - two*zb(i) + zb(i+1) + Fb(i))**2
       end do
       sum = sum + (za(N-1) - za(N) + ru + Fa(N))**2 + (zb(N-1) - zb(N) + ru + Fb(N))**2
       sum = dsqrt(sum/dfloat(N))

       da = rz; db = rz
       do i=1,N
          da = da + za(i)*sa(i)
          db = db + zb(i)*sb(i)
       end do
       d = da + db
      
       RL_a = za(N)-za(1); RL_b = zb(N)-zb(1);
       RL   = (RL_a + RL_b) / 2.0

       D0 = (d/(RL_a+RL_b)) / de
!      D0 = (d/(2.0*RL_0) ) / de ! Alternative def. (not used)

       eps = ru / (ru - 4.0*pi*D0)

       write(71,*) sngl(kappa), sngl(eps)
       write(72,*) sngl(kappa), sngl(sum)

       if(Vocal) then
          write(6,*) 'kappa:', sngl(kappa), sngl(eps), sngl(sum)
       else
          write(6,fl,advance='NO') CC, '------ Complete : ', ip , ' of ', Np
          flush(6)
       end if
              
    end do ip_loop

    close(unit=71); close(unit=72)

    write(*,*)
      
    if(flag) then
       write(6,f4) 'PF_eps: all data points up to ip=', ip_fail, ' were computed successfully'
    else
       write(6,f1) 'PF_eps: all data points computed successfully'
    end if

    stop
  end program PF_eps
