subroutine check_pars(info)
  use blocks
  use formats
  implicit none
  integer*4, intent(out) :: info
  
  integer*4              :: i

  info = 0

  open(unit=70, file='PF.par', status='old',err=100)
  read(70,*,err=101,end=101) N
  read(70,*,err=102,end=102) kappa
  read(70,*,err=103,end=103) e_min, e_max
  read(70,*,err=104,end=104) p_min, p_max
  read(70,*,err=105,end=105) Np
  read(70,*,err=106,end=106) th1, th2
  read(70,*,err=107,end=107) iter_max
  read(70,*,err=108,end=108) Vocal

  close(unit=70)

  write(6,f6) '............ Job : ', Job
  write(6,f2) '............. N  : ', N
  write(6,f2) '............. Np : ', Np
  write(6,f7) '.......... kappa : ', kappa
  write(6,f8) '.... e_min,e_max : ', e_min,e_max
  write(6,f8) '.... p_min,p_max : ', p_min,p_max
  write(6,f8) '........ th1,th2 : ', th1,th2
  if(iter_max .le. 0) then
     iter_max = 1e9
     write(6,f2) 'iter_max(changed): ', iter_max
  else
     write(6,f2) '....... iter_max : ', iter_max
  end if
!
!----------- 0) General Checks -------------------------------
!

  if(N .le. 1) then
     write(6,f1) '>>> Error on input: N<=1'
     info = 1
     return
  end if

  if(Np .lt. 2) then
     write(6,f1) '>>> Error on input: Np<2'
     info = 2
     return
  end if

  if(kappa .lt. rz) then
     write(6,f1) '>>> Error on input: kappa<0'
     info = 3
     return
  else if(kappa .le. small) then
     write(6,f1) '>>> Warning on input: kappa<=small'
     info = -1
  end if

  if     (th1 .lt. rz) then
     write(6,f1) '>>> Error on input: th1<0'
     info = 4
     return
  else if(th1 .eq. rz) then
     write(6,f1) '>>> Warning on input: th1=0'
     info = -2
  else if(th1 .gt. 0.1) then
     write(6,f1) '>>> Warning on input: th1>0.1'
     info = -3
  end if

  if     (th2 .lt. rz) then
     write(6,f1) '>>> Error on input: th2<0'
     info = 5
     return
  else if(th2 .eq. rz) then
     write(6,f1) '>>> Warning on input: th2=0'
     info = -4
  else if(th2 .gt. 0.1) then
     write(6,f1) '>>> Warning on input: th2>0.1'
     info = -5
  end if

!
!----------- 1) Ckecks for PF_alpha --------------------------
!

  IF(Job .eq. 'PF_alpha') THEN
     
     if(e_max .lt. rz) then
        write(6,f1) '>>> Error on input (PF_alpha) : e_max<0'
        info = 6
        return
     end if
     if(e_max .gt. 0.1) then
        write(6,f1) '>>> Warning on input (PF_alpha) : e_max>0.1'
        info = -6
     end if
     
     if(p_max .lt. rz) then
        write(6,f1) '>>> Error on input (PF_alpha) : p_max<0'
        info = 7
        return
     end if
     if(p_max .gt. 0.1) then
        write(6,f1) '>>> Warning on input (PF_alpha) : p_max>0.1'
        info = -7
     end if

!
!----------- 2) Checks for PF_e ------------------------------
!

  ELSE IF(Job .eq. 'PF_e') THEN

     if(e_min .lt. rz) then
        write(6,f1) '>>> Error on input (PF_e) : e_min<0'
        info = 8
        return
     end if
     if(e_max .lt. rz) then
        write(6,f1) '>>> Error on input (PF_e) : e_max<0'
        info = 9
        return
     end if
     if(e_min .gt. e_max) then
        write(6,f1) '>>> Error on input (PF_e): e_min>e_max'
        info = 10
        return
     end if
     if(p_min .lt. rz) then
        write(6,f1) '>>> Error on input (PF_e): p_min<0'
        info = 11
        return
     end if

!
!----------- 3) Checks for PF_eps ----------------------------
!

  ELSE IF(Job .eq. 'PF_eps') THEN

     if(e_max .lt. small) then
        write(6,f1) '>>> Error on input (PF_eps) : e_max<small'
        info = 12
        return
     end if

     if(p_min .lt. rz) then
        write(6,f1) '>>> Error on input (PF_eps): p_min<0'
        info = 13
        return
     end if

!
!----------- 4) Checks for PF_eta ----------------------------
!

  ELSE IF(Job .eq. 'PF_eta') THEN
     
     if(p_max .lt. rz) then
        write(6,f1) '>>> Error on input (PF_eta) : p_max<0'
        info = 14
        return
     end if
     if(p_max .gt. 0.1) then
        write(6,f1) '>>> Warning on input (PF_eta): p_max>0.1'
        info = -8
     end if

!
!----------- 5) Checks for PF_p ------------------------------
!

  ELSE IF(Job .eq. 'PF_p') THEN
     
     if(p_min .lt. rz) then
        write(6,f1) '>>> Error on input (PF_p) : p_min<0'
        info = 15
        return
     end if
     if(p_max .lt. rz) then
        write(6,f1) '>>> Error on input (PF_p): p_max<0'
        info = 16
        return
     end if
     if(p_max .le. p_min) then
        write(6,f1) '>>> Warning on input (PF_p): p_max<=p_min'
        info = -9
     end if

!
!----------- 6) Checks for PF_u ------------------------------
!

  ELSE IF(Job .eq. 'PF_u') THEN

     if(kappa .gt. 0.25) then
        write(6,f1) '>>> Warning on input (PF_u) : kappa>0.25'
        info = -10
     end if

  ELSE

     write(6,f6) '>>> Unexpected error: Wrong Job : ', Job
     info = 20
     return

  END IF

  allocate(sa(1:N)); allocate(sb(1:N))
  do i=1,N
     sa(i) = (-1)**i
  end do
  sb = -sa

  return

100 continue
  write(6,f1) '>>> Error opening PF.par'
  info = 100
  return

101 continue
  write(6,f1) '>>> Error reading [N]'
  info = 101
  return

102 continue
  write(6,f1) '>>> Error reading [kappa]'
  info = 102
  return

103 continue
  write(6,f1) '>>> Error reading [e_min,e_max]'
  info = 103
  return

104 continue
  write(6,f1) '>>> Error reading [p_min,p_max]'
  info = 105
  return

105 continue
  write(6,f1) '>>> Error reading [Np]'
  info = 105
  return

106 continue
  write(6,f1) '>>> Error reading [th1, th2]'
  info = 106
  return

107 continue
  write(6,f1) '>>> Error reading [iter_max]'
  info = 107
  return

108 continue
  write(6,f1) '>>> Error reading [Vocal]'
  info = 108
  return

end subroutine check_pars
